pub struct Parser(pub(crate) RootElementType);Expand description
Domain parser
Tuple Fields
0: RootElementTypeImplementations
Sourceimpl Parser
impl Parser
Sourcepub fn start_parsing(reactor_content: &str) -> Result<(String, Self), CMError>
pub fn start_parsing(reactor_content: &str) -> Result<(String, Self), CMError>
Create parser from xml content Returns id + object if suceeds
Sourcepub(crate) fn continue_parsing(
p: Parser,
root_dir: impl AsRef<Path>,
) -> Result<(DomainData, Option<GenerateContract>), CMError>
pub(crate) fn continue_parsing( p: Parser, root_dir: impl AsRef<Path>, ) -> Result<(DomainData, Option<GenerateContract>), CMError>
Parse domain and generate content in the root directory if needed Returns info about generated domain if suceeds
Sourcepub fn continue_parsing_with_path(
Parser: Parser,
root_dir: impl AsRef<Path>,
) -> Result<(DomainData, Option<GenerateContract>), CMError>
pub fn continue_parsing_with_path( Parser: Parser, root_dir: impl AsRef<Path>, ) -> Result<(DomainData, Option<GenerateContract>), CMError>
Parse domain and generate content at given abolute path if needed Returns info about generated domain if suceeds